@@ -3,7 +3,7 @@ use Moose::Role 'with';
 use Perl6::Junction;
 use Moose::Autobox;
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 with 'Moose::Autobox::Ref',
      'Moose::Autobox::List',
@@ -85,6 +85,14 @@ sub sort {
     [ CORE::sort { $sub->($a, $b) } @$array ]; 
 }    
 
+sub first {
+    $_[0]->[0];
+}
+
+sub last {
+    $_[0]->[$#{$_[0]}];
+}
+
 ## ::Indexed implementation
 
 sub at {
@@ -134,6 +142,17 @@ sub each_value {
     $sub->($_) for @$array;
 }
 
+sub each_n_values {
+    my ($array, $n, $sub) = @_;
+    my $it = List::MoreUtils::natatime($n, @$array);
+
+    while (my @vals = $it->()) {
+        $sub->(@vals);
+    }
+
+    return;
+}
+
 # end indexed
 
 sub flatten {
@@ -235,6 +254,10 @@ This is a role to describe operations on the Array type.
 
 =item B<flatten_deep ($depth)>
 
+=item B<first>
+
+=item B<last>
+
 =back
 
 =head2 Indexed implementation
@@ -259,6 +282,8 @@ This is a role to describe operations on the Array type.
 
 =item B<each_value>
 
+=item B<each_n_values ($n, $callback)>
+
 =back
 
 =head2 List implementation
